developerscripttools.RenameModulesScript
========================================

.. inheritance-diagram:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript
   :private-bases:

.. autoclass:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.alias

.. autoattribute:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.argument_parser

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.formatted_help

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.formatted_usage

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.formatted_version

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.long_description

.. autoattribute:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.program_name

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.scripting_group

.. autoattribute:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.short_description

.. autoattribute:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. autoattribute:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.version

Methods
-------

.. automethod:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.process_args

.. automethod:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.setup_argument_parser

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.__call__

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. automethod:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
